==> parse_server_sdk-0.0.3.tar.gz: lib/src/objects/parse_function.dart <==
part of flutter_parse_sdk;

class ParseCloudFunction extends ParseBase {
  final String functionName;
  String _path;
  bool _debug;
  ParseHTTPClient _client;

  ParseCloudFunction(this.functionName, {bool debug, ParseHTTPClient client}) {

    client == null ? _client = ParseHTTPClient() : _client = client;

    if (_debug == null) {
      _client.data.debug != null ? _debug = _client.data.debug : _debug = false;
    } else {
      _debug = _debug;
    }

    _path = "/functions/$functionName";
    setObjectData(Map<String, dynamic>());
  }

  execute([Map<String, dynamic> objectData]) async {
    var uri = _client.data.serverUrl + "$_path";
    setObjectData(objectData);
    var result = await _client.post(uri, body: JsonEncoder().convert(getObjectData()));
    return _handleResult(result, ParseApiFunctionCallType.execute);
  }

  ParseResponse _handleResult(Response response, ParseApiFunctionCallType type) {
    ParseResponse parseResponse = ParseResponse.handleResponse(this, response);
    Map<String, dynamic> responseData = JsonDecoder().convert(response.body);

    if (_client.data.debug || _debug) {
      var responseString = ' \n';

      responseString += "----"
          "\n${_client.data.appName} API Response ($functionName : ${ParseApiFunctionCallTypeUtil.getEnumValue(type)}) :";

      if (parseResponse.success && parseResponse.result != null) {
        responseString += "\nStatus Code: ${parseResponse.statusCode}";
        responseString += "\nPayload: ${responseData.toString()}";
      } else if (!parseResponse.success) {
        responseString += "\nStatus Code: ${responseData['code'] == null ? parseResponse.statusCode : responseData['code']}";
        responseString += "\nException: ${responseData['error'] == null ? responseData.toString() : responseData['error']}";
      }

      responseString += "\n----\n";
      print(responseString);
    }

    return parseResponse;
  }
}

==> parse_server_sdk-1.0.1.tar.gz: lib/src/objects/parse_function.dart <==
part of flutter_parse_sdk;

class ParseCloudFunction extends ParseBase {
  final String functionName;
  String _path;
  bool _debug;
  ParseHTTPClient _client;

  /// Creates a new cloud function object
  ///
  /// {https://docs.parseplatform.org/cloudcode/guide/}
  ParseCloudFunction(this.functionName, {bool debug, ParseHTTPClient client}) {
    client == null ? _client = ParseHTTPClient() : _client = client;
    _debug = isDebugEnabled(debug, _client);
    _path = "/functions/$functionName";
    setObjectData(Map<String, dynamic>());
  }

  /// Executes a cloud function
  ///
  /// To add the paramaters, create an object and call [set](value to set)
  execute() async {
    var uri = _client.data.serverUrl + "$_path";
    var result = await _client.post(uri, body: JsonEncoder().convert(getObjectData()));
    return _handleResult(result, ParseApiFunction.execute);
  }

  /// Handles an API response
  ParseResponse _handleResult(Response response, ParseApiFunction type) {
    ParseResponse parseResponse = ParseResponse.handleResponse(this, response);
    Map<String, dynamic> responseData = JsonDecoder().convert(response.body);

    if (_client.data.debug || _debug) {
      var responseString = ' \n';

      responseString += "----"
          "\n${_client.data.appName} API Response ($functionName : ${type.toString()}) :";

      if (parseResponse.success && parseResponse.result != null) {
        responseString += "\nStatus Code: ${parseResponse.statusCode}";
        responseString += "\nPayload: ${responseData.toString()}";
      } else if (!parseResponse.success) {
        responseString += "\nStatus Code: ${responseData['code'] == null ? parseResponse.statusCode : responseData['code']}";
        responseString += "\nException: ${responseData['error'] == null ? responseData.toString() : responseData['error']}";
      }

      responseString += "\n----\n";
      print(responseString);
    }

    return parseResponse;
  }
}
